..
    This file is part of Invenio.
    Copyright (C) 2015-2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

================
 Invenio-Assets
================

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-assets.svg
        :target: https://github.com/inveniosoftware/invenio-assets/blob/master/LICENSE

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-assets.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-assets

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-assets.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-assets

.. image:: https://img.shields.io/pypi/v/invenio-assets.svg
        :target: https://pypi.org/pypi/invenio-assets

Media assets management for Invenio.

* Provides the processing and bundling of JavaScript and CSS files.

* Provides CLI for installing and building media assets for Invenio via
  integration with Webpack and NPM.

Further documentation is available on
https://invenio-assets.readthedocs.io/
